==> slingpy-0.1.8-py3-none-any.whl: slingpy/apps/run_policies/hyperopt/exploration/abstract_exploration_strategy.py <==
"""
Copyright (C) 2021  Patrick Schwab, Arash Mehrjou, GlaxoSmithKline plc; Andrew Jesson, University of Oxford; Ashkan Soleymani, MIT

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions
 of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""
import six
from abc import ABCMeta, abstractmethod
from typing import Tuple, Dict, Union, List, Any, AnyStr


@six.add_metaclass(ABCMeta)
class AbstractExplorationStrategy(object):
    def __init__(self, hyperopt_param_ranges: Dict[AnyStr, Union[List, Tuple]]):
        """
        Abstract base exploration strategy.

        Args:
            hyperopt_param_ranges: The hyper-parameter optimization param ranges to select over.
        """
        self.hyperopt_param_ranges = hyperopt_param_ranges

    @abstractmethod
    def next(self, state: Any) -> Any:
        """
        Obtains the next hyper-parameter configuration in sequence.

        Args:
            state: Current iteration state.

        Returns:
            The next hyper-parameter configuration and the updated state.
        """
        raise NotImplementedError()

==> slingpy-0.2.12-py3-none-any.whl: slingpy/apps/run_policies/hyperopt/exploration/abstract_exploration_strategy.py <==
"""
Copyright (C) 2021  Patrick Schwab, Arash Mehrjou, GlaxoSmithKline plc; Andrew Jesson, University of Oxford; Ashkan Soleymani, MIT

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions
 of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""
from abc import ABCMeta, abstractmethod
from typing import Any, AnyStr, Dict, List, Tuple, Union


class AbstractExplorationStrategy(metaclass=ABCMeta):
    def __init__(self, hyperopt_param_ranges: Dict[AnyStr, Union[List, Tuple]]):
        """
        Abstract base exploration strategy.

        Args:
            hyperopt_param_ranges: The hyper-parameter optimization param ranges to select over.
        """
        self.hyperopt_param_ranges = hyperopt_param_ranges

    @abstractmethod
    def next(self, state: Any) -> Any:
        """
        Obtains the next hyper-parameter configuration in sequence.

        Args:
            state: Current iteration state.

        Returns:
            The next hyper-parameter configuration and the updated state.
        """
        raise NotImplementedError()
